@@ -133,8 +133,7 @@ FileCache *file_cache_new(const gchar * cache_dir, size_t max_size)
 {
     FileCache *cache = g_object_new(FILE_CACHE_TYPE, 0);
 
-    if (max_size >= 0)
-        cache->max_size = max_size;
+    cache->max_size = max_size;
     if (cache_dir) {
         g_free(cache->cache_dir);
         cache->cache_dir = g_strdup(cache_dir);
@@ -209,29 +208,32 @@ void file_cache_fill(FileCache * cache)
 
             fn = g_strconcat(cache->cache_dir, G_DIR_SEPARATOR_S,
                              dentry->d_name, 0);
-            fd = open(fn, O_RDONLY);
-            fsize = lseek(fd, 0, SEEK_END);
-            lseek(fd, 0, SEEK_SET);
-            if (read_safe(fd, &magic, sizeof(magic)) && (magic == MAGICHEAD)
-                && read_str_safe(fd, &url, fsize)) {
-                if (url) {
-                    entry = g_new0(CacheEntry, 1);
-                    if (read_str_safe(fd, &entry->id, fsize) &&
-                        read_safe(fd, &entry->refcount,
-                                  sizeof(gint) + sizeof(GTimeVal))) {
-                        entry->url = url;
-                        entry->filename = fn;
-                        entry->size = fsize;
-                        cache->current_size += fsize;
-                    } else {
-                        g_free(entry->id);
-                        g_free(entry);
-                        entry = NULL;
-                    }
-                } else
-                    g_free(url);
+            if (-1 != (fd = open(fn, O_RDONLY)))
+            {
+                fsize = lseek(fd, 0, SEEK_END);
+                lseek(fd, 0, SEEK_SET);
+                if (read_safe(fd, &magic, sizeof(magic)) && (magic == MAGICHEAD)
+                    && read_str_safe(fd, &url, fsize)) {
+                    if (url) {
+                        entry = g_new0(CacheEntry, 1);
+                        if (read_str_safe(fd, &entry->id, fsize) &&
+                            read_safe(fd, &entry->refcount,
+                                      sizeof(gint) + sizeof(GTimeVal))) {
+                            entry->url = url;
+                            entry->filename = fn;
+                            entry->size = fsize;
+                            cache->current_size += fsize;
+                        } else {
+                            g_free(entry->id);
+                            g_free(entry);
+                            entry = NULL;
+                        }
+                    } else
+                        g_free(url);
+                }
+                close(fd);
             }
-            close(fd);
+
             if (entry) {
                 //maybe search in the cache first to remove duplicate files
                 g_hash_table_insert(cache->hash, url, entry);
@@ -242,7 +244,6 @@ void file_cache_fill(FileCache * cache)
                 unlink(fn);
                 g_free(fn);
             }
-
         }
     }
 
@@ -268,15 +269,13 @@ void remove_unwanted_entries(FileCache * cache, gint size)
 {
     CacheEntry *entry = NULL;
     while (size > 0 && (entry = CACHE_ENTRY(g_queue_pop_head(cache->queue)))) {
-        if (entry->refcount>1) {
-            size -= entry->size;
-            cache->current_size -= entry->size;
-            unlink(entry->filename);
-            //TODO: Check why the entry->url could be NULL in some reason
-            if (cache->hash && entry->url) {
-                g_hash_table_remove(cache->hash, entry->url);
-            }
-        }
+	size -= entry->size;
+	cache->current_size -= entry->size;
+	unlink(entry->filename);
+	//TODO: Check why the entry->url could be NULL in some reason
+	if (cache->hash && entry->url) {
+	    g_hash_table_remove(cache->hash, entry->url);
+	}
     }
 }
 
@@ -455,18 +454,15 @@ gboolean file_cache_can_resize(FileCache * cache, size_t new_size)
 
     gboolean result = FALSE;
 
-    if (new_size >= 0) {
+    if (new_size > cache->max_size) {
+        struct statfs info;
 
-        if (new_size > cache->max_size) {
-            struct statfs info;
+        result =
+            (statfs(cache->cache_dir, &info) == 0) &&
+            (info.f_bavail * info.f_bsize > new_size - cache->max_size);
+    } else
+        result = TRUE;
 
-            result =
-                (statfs(cache->cache_dir, &info) == 0) &&
-                (info.f_bavail * info.f_bsize > new_size - cache->max_size);
-        } else
-            result = TRUE;
-
-    }
 
     return result;
 }
@@ -475,21 +471,17 @@ void file_cache_resize(FileCache * cache, size_t new_size)
 {
     g_assert(IS_FILE_CACHE(cache));
 
-    if (new_size >= 0) {
-
-        if (!new_size) {
-            //remove the entire cache
-            while (g_queue_pop_head(cache->queue)) ;
-            g_hash_table_foreach_remove(cache->hash, remove_file, NULL);
-        } else {
-            //remove the excess elements from the cache if needed
-            if (cache->current_size > new_size)
-                remove_unwanted_entries(cache,
-                                        cache->current_size - new_size);
-        }
-        cache->max_size = new_size;
-
+    if (!new_size) {
+        //remove the entire cache
+        while (g_queue_pop_head(cache->queue)) ;
+        g_hash_table_foreach_remove(cache->hash, remove_file, NULL);
+    } else {
+        //remove the excess elements from the cache if needed
+        if (cache->current_size > new_size)
+            remove_unwanted_entries(cache,
+                                    cache->current_size - new_size);
     }
+    cache->max_size = new_size;
 }
 
 size_t file_cache_size(FileCache * cache)
@@ -526,11 +518,9 @@ file_cache_find(FileCache * cache, const gchar * lurl, size_t * size,
     CacheEntry *entry = NULL;
     gint fsize;
     gint cpos;
-    gint fd = 0, fdnew = 0;
+    gint fd = 0;
     gint len;
     gchar *url = strip_url(lurl);
-    gchar *tmp = NULL;
-    gboolean rename_needed = FALSE;
 
     g_assert(IS_FILE_CACHE(cache));
 
@@ -539,66 +529,7 @@ file_cache_find(FileCache * cache, const gchar * lurl, size_t * size,
     if (url && cache->max_size
         && (entry = g_hash_table_lookup(cache->hash, url))) {
         entry->refcount++;
-        if (increase_statistic) {
-            tmp = g_strconcat(cache->cache_dir,
-                              G_DIR_SEPARATOR_S, "chXXXXXX", 0);
-            fdnew = mkstemp(tmp);
-            if (fdnew != -1) {
-                GnomeVFSResult copy_result;
-                GnomeVFSURI *src = NULL, *dest = NULL;
-                gchar *src_uri = NULL, *dest_uri = NULL;
-                GnomeVFSFileInfo *finfo = NULL;
-                finfo = gnome_vfs_file_info_new();
-                close(fdnew);
-                dest_uri = gnome_vfs_get_uri_from_local_path(tmp);
-                src_uri = gnome_vfs_get_uri_from_local_path(entry->filename);
-                src = gnome_vfs_uri_new(src_uri);
-                dest = gnome_vfs_uri_new(dest_uri);
-                copy_result =
-                    gnome_vfs_get_file_info_uri(src, finfo,
-                                                GNOME_VFS_FILE_INFO_DEFAULT);
-                if (copy_result != GNOME_VFS_OK
-                    || finfo->type != GNOME_VFS_FILE_TYPE_REGULAR) {
-                    g_warning("Selected cache content is not correct!!!");
-                    g_free(src_uri);
-                    g_free(dest_uri);
-                    gnome_vfs_uri_unref(src);
-                    gnome_vfs_uri_unref(dest);
-                    gnome_vfs_file_info_unref(finfo);
-                    g_free(tmp);
-                    return NULL;
-                }
-                gnome_vfs_file_info_unref(finfo);
-                copy_result =
-                    gnome_vfs_xfer_uri(src, dest, GNOME_VFS_XFER_DEFAULT,
-                                       GNOME_VFS_XFER_ERROR_MODE_ABORT,
-                                       GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
-                                       NULL, NULL);
-                if (copy_result == GNOME_VFS_OK) {
-                    if ((fd = open(tmp, O_RDWR)) != -1) {
-                        rename_needed = TRUE;
-                    } else {    //unable to open
-                        increase_statistic = FALSE;
-                        unlink(tmp);
-                        fd = open(entry->filename, O_RDWR);
-                    }
-
-                } else {        //no more space to copy the file
-                    increase_statistic = FALSE;
-                    unlink(tmp);
-                    fd = open(entry->filename, O_RDWR);
-                }
-                g_free(src_uri);
-                g_free(dest_uri);
-                gnome_vfs_uri_unref(src);
-                gnome_vfs_uri_unref(dest);
-            } else {            // now more space to open the file
-                increase_statistic = FALSE;
-                fd = open(entry->filename, O_RDWR);
-            }
-        } else {                //not needed to modify the file, we will just read that
-            fd = open(entry->filename, O_RDWR);
-        }
+	fd = open(entry->filename, O_RDWR);
         //    ULOG_DEBUG("#####Cache find: found");
         if (fd != -1) {
             fsize = lseek(fd, 0, SEEK_END);
@@ -620,26 +551,17 @@ file_cache_find(FileCache * cache, const gchar * lurl, size_t * size,
                     *size = len;
                 result = (gpointer) g_try_malloc(len);
                 if (result) {
-                    read_safe(fd, result, len);
-                    close(fd);
-                    if (rename_needed) {    //deleting old file, rename tempfile for that
-                        unlink(entry->filename);
-                        rename(tmp, entry->filename);
+                    if (!read_safe(fd, result, len))
+                    {
+                        ULOG_DEBUG("read failed");
                     }
+                    close(fd);
                     //    ULOG_DEBUG("#####Cache find: loaded");
                     g_free(url);
-                    g_free(tmp);
                     return result;
                 }
             }
 
-            if (rename_needed) {    //temporary file was created, only that was modified. Deleting only that
-                unlink(tmp);
-            } else {
-
-                //damaged file ... remove it
-                unlink(entry->filename);
-            }
         }
         //    ULOG_DEBUG("#####Cache find: something wrong");
         //damaged hash entry ... remove it
@@ -650,9 +572,7 @@ file_cache_find(FileCache * cache, const gchar * lurl, size_t * size,
     if (size)
         *size = 0;
 
-
     g_free(url);
-    g_free(tmp);
     return NULL;
 }
 
