@@ -28,7 +28,6 @@
 #include <libxml/uri.h>
 #include <string.h>
 #include <time.h>
-#include <osso-ic-gconf.h>
 #include <osso-log.h>
 
 #include <osso-rss-feed-reader/settings.h>
@@ -194,15 +193,6 @@ conf_internet_connection_changed_cb(GConfClient * gconfclient,
         return;
 
     app_ui_data = app_data->app_ui_data;
-
-    struct tm *tm;
-
-    tm = localtime(&rss_updated);
-    ULOG_DEBUG("Last refresh: %d:%d", tm->tm_hour, tm->tm_min);
-    ULOG_DEBUG("Search mode: %d", app_ui_data->search_mode);
-    ULOG_DEBUG("Automatic updates: %d",
-               getBooleanConfValue(RSS_SETTINGS_AUTOMATIC_UPDATES));
-
 }
 
 static void
@@ -298,20 +288,12 @@ void conf_init()
     gconf_client_notify_add(gconfclient, "/system/http_proxy",
                             conf_proxy_reset_settings_cb, NULL, NULL, NULL);
 
-    gconf_client_add_dir(gconfclient, ICD_GCONF_CURRENT,
-                         GCONF_CLIENT_PRELOAD_NONE, NULL);
-
-    gconf_client_notify_add(gconfclient, ICD_GCONF_CURRENT,
-                            conf_internet_connection_changed_cb, NULL, NULL,
-                            NULL);
-
     gconf_client_add_dir(gconfclient, RSS_SETTINGS_IMAGE_CACHE_SIZE,
                          GCONF_CLIENT_PRELOAD_NONE, NULL);
 
     gconf_client_notify_add(gconfclient, RSS_SETTINGS_IMAGE_CACHE_SIZE,
                             configuration_changed_cb, NULL, NULL, NULL);
 
-    find_iap_connection_type();
 
     /* Load settings into static buffers */
     conf_proxy_reset_settings_cb(NULL, 0, NULL, NULL);
@@ -686,12 +668,13 @@ void setStringConfValue(gchar * valuename, gchar * value)
     g_assert(valuename != NULL);
     g_assert(gconfclient != NULL);
 
-    gcv = gconf_value_new(GCONF_VALUE_STRING);
-    gconf_value_set_string(gcv, value);
-    gconf_client_set(gconfclient, valuename, gcv, &err);
-    if (gcv)
+    if ((gcv = gconf_value_new(GCONF_VALUE_STRING)))
+    {
+        gconf_value_set_string(gcv, value);
+        gconf_client_set(gconfclient, valuename, gcv, &err);
         gconf_value_free(gcv);
-    is_gconf_error(&err);
+        is_gconf_error(&err);
+    }
 }
 
 gchar *getStringConfValue(gchar * valuename)
