@@ -27,8 +27,6 @@
 #include <conbtdialogs-dbus.h>
 #include <conic.h>
 
-#include <osso-ic-dbus.h>
-
 #include <osso-rss-feed-reader/settings.h>
 #include <osso-rss-feed-reader/dbus.h>
 
@@ -153,7 +151,9 @@ static void handle_iap_connected(AppUIData * app_ui_data,
             ULOG_DEBUG("Autoupdate: type=%d, bearer=%s", type, bearer);
 
             
-            if (((type == 0 && strncasecmp(bearer, "WLAN", 4) == 0) ||
+            if (((type == 0 && 
+                    (strncasecmp(bearer, "WLAN", 4) == 0 || 
+                     strncasecmp(bearer, "WIMAX", 5) == 0)) ||
                 (type == 1)) && check_if_autorefresh_needed())
             {
                 ui_feedlist_do_for_all(NULL, ACTION_FILTER_FEED,
@@ -734,13 +734,10 @@ gboolean init_osso(AppData * app_data)
     app_data->osso =
         osso_initialize(PACKAGE_NAME, PACKAGE_VERSION, TRUE, NULL);
 
-    g_assert(app_data->osso);
-
     if (app_data->osso == NULL) {
         ULOG_CRIT("Osso initialization failed");
         return FALSE;
     }
-    g_assert(app_data->osso);
 
     /* Set topping callback */
     /*    osso_application_set_top_cb(app_data->osso,
@@ -858,7 +855,6 @@ gboolean deinit_osso(AppData * app_data)
 
     g_assert(app_data->osso);
     osso_deinitialize(app_data->osso);
-    /* TODO: unregister osso_iap_cb() here */
 
     return TRUE;
 }
@@ -875,13 +871,11 @@ gboolean open_url(gchar * url)
     g_assert(app_data != NULL);
     g_assert(app_data != NULL);
 
-    osso_rpc_run_with_defaults(app_data->osso,
-                               "osso_browser",
-                               reuseWindow ? OSSO_BROWSER_LOAD_URL_REQ :
-                               OSSO_BROWSER_OPEN_NEW_WINDOW_REQ, NULL,
-                               DBUS_TYPE_STRING, url, DBUS_TYPE_INVALID);
-
-    return TRUE;
+    return osso_rpc_run_with_defaults(app_data->osso,
+                                      "osso_browser",
+                                      reuseWindow ? OSSO_BROWSER_LOAD_URL_REQ :
+                                      OSSO_BROWSER_OPEN_NEW_WINDOW_REQ, NULL,
+                                      DBUS_TYPE_STRING, url, DBUS_TYPE_INVALID);
 }
 
 gboolean _rss_dbus_signal_applet(gchar * signal)
@@ -1002,10 +996,3 @@ static void free_iap_type()
     }
 }
 
-void find_iap_connection_type()
-{
-    free_iap_type();
-
-    app_data->app_ui_data->network_iap =
-        getStringConfValue(ICD_GCONF_CURRENT);
-}
