@@ -366,7 +366,7 @@ static void import_parse_outline(xmlNodePtr cur, folderPtr folder,
                 fp = feed_new();
             } else if (mode == RSS_CONFIG_MODE_STATE) {
                 gchar *sid = xmlGetProp(cur, BAD_CAST "id");
-                if (sid) {
+                if (id && sid) {
                     fp = (feedPtr) ui_feedlist_find_feed(NULL, id);
                     if (fp == NULL) {
                         xmlFree(sid);
@@ -378,8 +378,13 @@ static void import_parse_outline(xmlNodePtr cur, folderPtr folder,
                 }
             }
         }
+        if (!fp) {
+            goto contin;
+        }
+
         fp->fhp = feed_type_str_to_fhp(typeStr);
 
+
         /* Set the cache limit */
         cacheLimitStr = xmlGetProp(cur, BAD_CAST "cacheLimit");
         if (cacheLimitStr != NULL && !xmlStrcmp(cacheLimitStr, "unlimited")) {
