@@ -21,19 +21,7 @@
 #ifndef _FAVICON_H
 #define _FAVICON_H
 
-#include "feed.h"
-
-/** Loads a favicon for the given feed
-  *
-  * @param fp a pointer to a feed
-  */
-void favicon_load(feedPtr fp);
-
-/** Removes a favicon from the cache
-  *
-  * @param fp a pointer to a feed
-  */
-void favicon_remove(feedPtr fp);
+#include "feed_types.h"
 
 /** Downloads a favicon
   *
