@@ -615,7 +615,12 @@ void feed_add_items_delete_old(feedPtr fp, GList * items)
      * mean to reverse there order. */
     iter = g_list_last(items);
     while (iter != NULL) {
-        if (feed_add_item_ignore_old(fp, ((itemPtr) iter->data)) &&
+       gboolean result = feed_add_item_ignore_old(fp, ((itemPtr) iter->data));
+       if(!result) {
+           iter->data = NULL;
+       }
+
+        if (result &&
             !item_added)
             item_added = TRUE;
         iter = g_list_previous(iter);
