@@ -360,34 +360,34 @@ static void url_requested_cb(GtkHTML * html, const gchar * url,
                 gtk_html_stream_write(stream, buf, size);
             }
             gtk_html_stream_close(stream,
-                                  size == -1
-                                  ? GTK_HTML_STREAM_ERROR
-                                  : GTK_HTML_STREAM_OK);
+                    size == -1
+                    ? GTK_HTML_STREAM_ERROR
+                    : GTK_HTML_STREAM_OK);
             close(fd);
 
             return;
         }
     } else
         if ((buf =
-             file_cache_find(app_data->app_ui_data->img_cache, url, &size,
-                             TRUE))) {
-        //try to find it in the cache
-        write_image((gpointer) stream, buf, size);
-        g_free(buf);
-    } else {
-        gboolean load_image = app_data->app_ui_data->load_url &&
-            (strcmp(app_data->app_ui_data->load_url, url) == 0);
-        if ((load_image
-             || (load_images
-                 && feed_get_download_images((feedPtr) displayed_node)))
-            && (app_data->app_ui_data->search_mode != SFM_SEARCH)) {
-            //URL reqested from the internet
-            download_queue_image(url, (gpointer) stream, load_image);
-            if (load_image)
-                load_done_cb(GTK_WIDGET(html), NULL);
-        } else
-            gtk_html_stream_close(stream, GTK_HTML_STREAM_ERROR);
-    }
+                    file_cache_find(app_data->app_ui_data->img_cache, url, &size,
+                        TRUE))) {
+            //try to find it in the cache
+            write_image((gpointer) stream, buf, size);
+            g_free(buf);
+        } else if (url) {
+            gboolean load_image = app_data->app_ui_data->load_url &&
+                (strcmp(app_data->app_ui_data->load_url, url) == 0);
+            if ((load_image
+                        || (load_images
+                            && feed_get_download_images((feedPtr) displayed_node)))
+                    && (app_data->app_ui_data->search_mode != SFM_SEARCH)) {
+                //URL reqested from the internet
+                download_queue_image(url, (gpointer) stream, load_image);
+                if (load_image)
+                    load_done_cb(GTK_WIDGET(html), NULL);
+            } else
+                gtk_html_stream_close(stream, GTK_HTML_STREAM_ERROR);
+        }
 
     return;
 }
@@ -424,7 +424,7 @@ void post_url(const gchar * url, gboolean bluetooth)
                     fp = (feedPtr) displayed_node;
             }
 
-            if ((strcmp(fp->id, tmp[0]) != 0) && (fp->type != FST_VFOLDER)) {
+            if (fp && (strcmp(fp->id, tmp[0]) != 0) && (fp->type != FST_VFOLDER)) {
                 g_warning("we are rendering some _real_ feed "
 			  "which is not the tobe displayed feed!!!ERRORS\n\n");
                 // free stuff
@@ -434,7 +434,7 @@ void post_url(const gchar * url, gboolean bluetooth)
             }
 
             ip_nr = (gulong) g_strtod(tmp[1], NULL);
-            ip = feed_lookup_item_by_nr_extended(fp, ip_nr, tmp[0]);
+            if (fp) ip = feed_lookup_item_by_nr_extended(fp, ip_nr, tmp[0]);
 
             if (ip == NULL) {
                 g_warning
@@ -583,7 +583,7 @@ static gboolean object_requested_cb(GtkHTML * html, GtkHTMLEmbedded * ew)
                     \n\n");
         return FALSE;
     }
-    if ((strcmp(fp->id, tmp[0]) != 0) && (fp->type != FST_VFOLDER)) {
+    if (!fp || ((strcmp(fp->id, tmp[0]) != 0) && (fp->type != FST_VFOLDER))) {
         fprintf(stderr,
                 "object_requested_cb: we are rendering some _real_ feed \
                     which is not the tobe displayed feed!!!ERRORS\n\n");
@@ -790,25 +790,37 @@ void grab_focus(GtkHTML * html, gint x, gint y, gboolean forward)
 {
     HTMLObject *obj = NULL;
     gint offset = 0;
+    gint height = 0;
 
     if (!html)
         html = GTK_HTML(gtk_bin_get_child
                         (GTK_BIN(app_data->app_ui_data->html_scrollpane)));
 
+    height = html_engine_get_doc_height(html->engine);
+
     //search for a focusable object
-    // FIXME: This loop can come busy if html_engine_get_object_at returns allways null..
     while (!obj || html_object_is_container(obj)) {
         obj = html_engine_get_object_at(html->engine, x, y, &offset, TRUE);
 
         if (!obj || html_object_is_container(obj)) {
-            if (forward)
-                y += 5;
-            else
-                y -= 5;
+            if (forward) {
+                /*make sure the loop will not be infinite fix NB#79981 */
+                if (y < height - 5)
+	                y += 5;
+		else
+			break;
+	    } else {
+                /*make sure the loop will not be infinite fix NB#79981*/
+                if (5 < y)
+                	y -= 5;
+		else
+			break;
+	    }
         }
     }
 
-    g_object_set_data(G_OBJECT(html), "last-focus", (gpointer) obj);
+    if (obj != NULL)
+        g_object_set_data(G_OBJECT(html), "last-focus", (gpointer) obj);
 }
 
 void grab_top_focus()
@@ -1132,9 +1144,6 @@ gchar *gtkhtml_just_render_item(itemPtr ip, gboolean forDisplay)
                     g_strconcat(enclosures, " ", encl_attr->type, NULL);
             }
             if (encl_attr->length > 0) {
-                if (encl_length) {
-                    g_free(encl_length);
-                }
                 formatlegth = encl_attr->length;
                 /*Lets format the length */
                 if (formatlegth > 1024) {   /* KB */
@@ -1505,7 +1514,6 @@ void gtkhtml_write_html(GtkWidget * scrollpane, gchar * string,
 
     g_free(fp_head);
 
-    gtk_html_images_unref(html);
     render_list = render_list_head = itemlistgs;
     idle_id = g_idle_add(render_one_item, NULL);
 }
@@ -1595,8 +1603,6 @@ void gtkhtml_start_write_search_feed(nodePtr node)
          (gtk_bin_get_child
           (GTK_BIN(app_data->app_ui_data->html_scrollpane))));
 
-    gtk_html_images_unref(html);
-
     /* Real html widget now */
     fp_head = gtkhtml_render_head((feedPtr) node);
     gtk_html_stream_write(search_fd_stream_handle,
@@ -1976,8 +1982,8 @@ void gtkhtml_display_empty_feed(feedPtr fp)
 
 static gchar *_render_description(itemPtr ptr) {
     const gchar *buff = item_get_description(ptr);
-    gchar **arr;
-    gchar **arr2;
+    gchar **arr = NULL;
+    gchar **arr2 = NULL;
     int x = 0;
     int y = 0;
     gchar *s = NULL;
@@ -1991,8 +1997,10 @@ static gchar *_render_description(itemPtr ptr) {
     gchar *baz2 = NULL;
 
 
-    arr = g_strsplit_set(buff," ",-1);
-   
+    if (buff) {
+        arr = g_strsplit_set(buff," ",-1);
+    } 
+
     if (arr) {
         while ( (gchar *) arr[x] != NULL) {
             foo = arr[x];
