@@ -139,7 +139,7 @@ static gchar *search_links(const gchar * data, int type, gboolean favicon)
         endptr = strchr(ptr, '>');
         if (endptr == NULL)
             return NULL;
-	tstr = g_strndup(ptr, endptr - ptr - 1);
+	tstr = g_strndup(ptr, endptr - ptr);
 
         res = ((type == 0) ?
                (favicon ? checkLinkRefForFavicon(tstr) : checkLinkRef(tstr))
