@@ -28,7 +28,7 @@
 
 #include "htmlview.h"
 
-#include <ossoemailinterface.h>
+#include <libmodest-dbus-client/libmodest-dbus-client.h>
 #include <osso-log.h>
 
 extern AppData *app_data;
@@ -87,29 +87,20 @@ void ui_htmlview_set_proxy(gchar * hostname, int port, gchar * username,
 
 int send_text_via_email(const gchar * post)
 {
+    gboolean ret = FALSE;
+
     g_assert(NULL != post);
     g_assert(app_data != NULL);
 
-    osso_return_t retcode = osso_email_url_email(app_data->osso,
-                                                 post);
+    ret = libmodest_dbus_client_compose_mail(app_data->osso, NULL /* to */,
+                NULL /* cc */, NULL /* bcc */, NULL /* subject */,
+                post /* body */, NULL /* attachments */);
 
     /* CHECK: There is no error feedback defined in UI spec. */
-    switch (retcode) {
-        case OSSO_OK:
-            ULOG_DEBUG("osso_email_url_email() returned OK!\n");
-            break;
-        case OSSO_ERROR:
-            ULOG_DEBUG("osso_email_url_email() returned ERROR!\n");
-            break;
-        case OSSO_INVALID:
-            ULOG_DEBUG("osso_email_url_email() returned INVALID!\n");
-            break;
-        case OSSO_RPC_ERROR:
-            ULOG_DEBUG("osso_email_url_email() returned OSSO_RPC_ERROR!\n");
-            break;
-        default:
-            ULOG_DEBUG("osso_email_url_email() returned %d!\n", retcode);
-            break;
+    if (ret) {
+        ULOG_DEBUG("libmodest_dbus_client_compose_mail() returned TRUE!\n");
+    } else {
+        ULOG_DEBUG("libmodest_dbus_client_compose_mail() returned FALSE!\n");
     }
 
     return 0;
