@@ -241,6 +241,12 @@ GtkWidget *create_mainwindow(AppUIData * app_ui_data)
     menubar = GTK_WIDGET(gtk_menu_new());
     gtk_menu_set_accel_group(GTK_MENU(menubar), gtk_accel_group_new());
     ULOG_DEBUG("*** creating menubar - feed");
+    
+    // add accelerator group to the main window
+    gtk_window_add_accel_group(GTK_WINDOW(mainwindow),
+                               gtk_menu_get_accel_group(GTK_MENU(menubar)));
+
+
 
     menuitem_feed = gtk_menu_item_new_with_label(_("rss_me_feed"));
     gtk_widget_show(menuitem_feed);
@@ -278,8 +284,8 @@ GtkWidget *create_mainwindow(AppUIData * app_ui_data)
     ULOG_DEBUG("*** creating menubar - edit");
 
     menuitem_edit = gtk_menu_item_new_with_label(_("rss_me_edit"));
-    gtk_widget_show(menuitem_edit);
     gtk_container_add(GTK_CONTAINER(menubar), menuitem_edit);
+    gtk_widget_show(menuitem_edit);
 
     menuitem_edit_menu = gtk_menu_new();
     gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem_edit),
@@ -604,11 +610,6 @@ GtkWidget *create_mainwindow(AppUIData * app_ui_data)
     app_ui_data->context_menuitem_save_image = GTK_MENU_ITEM(menuitem);
 
 
-    // add accelerator group to the main window
-    gtk_window_add_accel_group(GTK_WINDOW(mainwindow),
-                               gtk_menu_get_accel_group(GTK_MENU(menubar)));
-
-
     ULOG_DEBUG("*** creating newsbox");
     newsbox = gtk_hpaned_new();
     gtk_widget_show(newsbox);
@@ -804,10 +805,10 @@ GtkWidget *create_mainwindow(AppUIData * app_ui_data)
                      G_CALLBACK(on_menuitem_sort), app_ui_data);
 
     g_signal_connect((gpointer) menuitem_normal, "activate",
-                     G_CALLBACK(toggle_toolbar), NULL);
+                     G_CALLBACK(toggle_toolbar_cb), app_ui_data);
 
     g_signal_connect((gpointer) menuitem_full, "activate",
-                     G_CALLBACK(toggle_toolbar), NULL);
+                     G_CALLBACK(toggle_toolbar_cb), app_ui_data);
 
     g_signal_connect((gpointer) menuitem_fullscreen, "activate",
                      G_CALLBACK(on_toggle_fullscreen_mode), NULL);
@@ -1134,7 +1135,10 @@ gboolean key_press(GtkWidget * widget, GdkEventKey * event,
             if (gtk_window_get_focus(GTK_WINDOW(app_ui_data->main_view)) ==
                 feedlist)
                 return tree_view_cycle_up(feedlist);
-            else {
+            
+            if (!GTK_IS_EDITABLE
+                     (gtk_window_get_focus
+                      (GTK_WINDOW(app_ui_data->main_view)))) {
                 ULOG_DEBUG("<<<key-press: On the page now ");
                 key_press_nr++;
                 //if up_key_press_nr == 1) we will handle in release-key
@@ -1146,6 +1150,8 @@ gboolean key_press(GtkWidget * widget, GdkEventKey * event,
                     return FALSE;
                 }
             }
+            // focus is on search field, drop the event
+            return TRUE;
 
             break;
         /*
@@ -1161,8 +1167,9 @@ gboolean key_press(GtkWidget * widget, GdkEventKey * event,
             if (gtk_window_get_focus(GTK_WINDOW(app_ui_data->main_view)) ==
                 feedlist)
                 return tree_view_cycle_down(feedlist);
-
-            else {
+            if (!GTK_IS_EDITABLE
+                     (gtk_window_get_focus
+                      (GTK_WINDOW(app_ui_data->main_view)))) {
                 ULOG_DEBUG("<<<key-press: On the page now ");
                 key_press_nr++;
                 //if down_key_press_nr == 1) we will handle in release-key
@@ -1174,6 +1181,8 @@ gboolean key_press(GtkWidget * widget, GdkEventKey * event,
                     return FALSE;
                 }
             }
+            // focus is on search field, drop the event
+            return TRUE;
             break;
 
 
@@ -1209,6 +1218,11 @@ gboolean key_press(GtkWidget * widget, GdkEventKey * event,
             break;
 
         default:
+            // If we get a keypress and focus is in feedlist or htmlview then
+            // we should allways move the focus to search field..
+            if (GTK_WIDGET_HAS_FOCUS(feedlist) || GTK_WIDGET_HAS_FOCUS(gtk_bin_get_child(GTK_BIN(ui_mainwindow_get_active_htmlview())))) {
+                gtk_widget_grab_focus(GTK_WIDGET(app_ui_data->search_field));
+            }
             break;
     }
     return FALSE;
@@ -1743,7 +1757,7 @@ GtkWidget *create_manage_folders_dialog(void)
     gtk_container_add(GTK_CONTAINER(dialog_vbox), folder_scrollwindow);
 
     gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(folder_view), FALSE);
-    gtk_tree_view_set_reorderable(GTK_TREE_VIEW(folder_view), FALSE);
+    gtk_tree_view_set_reorderable(GTK_TREE_VIEW(folder_view), TRUE);
 
     dialog_action_area = GTK_DIALOG(mf_dialog)->action_area;
     gtk_widget_show(dialog_action_area);
@@ -1773,6 +1787,9 @@ GtkWidget *create_manage_folders_dialog(void)
     g_signal_connect(G_OBJECT(mf_dialog), "key-press-event",
                      G_CALLBACK(key_press_for_cancelling_dialog), NULL);
 
+    g_signal_connect((gpointer) folder_view, "drag_end",
+                                 G_CALLBACK(on_feedlist_drag_end), NULL);
+
     GTK_WIDGET_SET_FLAGS(mf_renamebtn, GTK_CAN_DEFAULT);
     GTK_WIDGET_SET_FLAGS(mf_deletebtn, GTK_CAN_DEFAULT);
     GTK_WIDGET_SET_FLAGS(mf_closebtn, GTK_CAN_DEFAULT);
@@ -1833,7 +1850,7 @@ GtkWidget *create_change_folder_dialog(GtkWindow * parent)
     gtk_container_add(GTK_CONTAINER(dialog_vbox), folder_scrollwindow);
 
     gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(folder_view), FALSE);
-    gtk_tree_view_set_reorderable(GTK_TREE_VIEW(folder_view), TRUE);
+    gtk_tree_view_set_reorderable(GTK_TREE_VIEW(folder_view), FALSE);
 
 
     dialog_action_area = GTK_DIALOG(cf_dialog)->action_area;
@@ -1856,9 +1873,6 @@ GtkWidget *create_change_folder_dialog(GtkWindow * parent)
     gtk_dialog_add_action_widget(GTK_DIALOG(cf_dialog), cf_cancelbtn,
                                  GTK_RESPONSE_CANCEL);
 
-    g_signal_connect((gpointer) folder_view, "drag_end",                           
-                     G_CALLBACK(on_feedlist_drag_end), NULL);
-
     GLADE_HOOKUP_OBJECT_NO_REF(cf_dialog, cf_dialog, "cf_dialog");
     GLADE_HOOKUP_OBJECT_NO_REF(cf_dialog, dialog_vbox, "vbox");
     GLADE_HOOKUP_OBJECT(cf_dialog, folder_view, "folder_view");
@@ -2288,22 +2302,6 @@ void refresh_insens_messages(AppUIData * app_ui_data)
     }
 }
 
-void paste_insens_messages(AppUIData * app_ui_data)
-{
-    GtkClipboard *clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
-    if (gtk_clipboard_wait_is_text_available(clipboard)) {
-        hildon_helper_set_insensitive_message(GTK_WIDGET
-                                              (app_ui_data->menuitem_paste),
-                                              _("rss_ib_unable_to_paste"));
-
-    } else {
-        hildon_helper_set_insensitive_message(GTK_WIDGET
-                                              (app_ui_data->menuitem_paste),
-                                              _("rss_ib_nothing_to_paste"));
-
-    }
-}
-
 void close_all_opened_dialog(AppData * app_data)
 {
     g_assert(app_data);
@@ -2341,6 +2339,11 @@ void close_all_opened_dialog(AppData * app_data)
 
     if (app_ui_data->propdialog != NULL) {
 
+        if (app_ui_data->unsubscribe_dialog) {
+            gtk_widget_destroy(app_ui_data->unsubscribe_dialog);
+            app_ui_data->unsubscribe_dialog = NULL;
+        }
+
         app_ui_data->dlg_btn_unsubscribe = NULL;
         app_ui_data->dialog = NULL;
         gtk_widget_destroy(GTK_WIDGET(app_ui_data->propdialog));
@@ -2384,6 +2387,9 @@ gboolean ui_update_edit_menu( gpointer user_data )
     gtk_widget_set_sensitive(GTK_WIDGET(app_ui_data->menuitem_selectall),
                              FALSE);
 
+    hildon_helper_set_insensitive_message(GTK_WIDGET
+                                          (app_ui_data->menuitem_paste),
+                                          _("rss_ib_nothing_to_paste"));
     if (NULL != app_ui_data->dialog)
         focus = gtk_window_get_focus(GTK_WINDOW(app_ui_data->dialog));
     else
@@ -2401,11 +2407,19 @@ gboolean ui_update_edit_menu( gpointer user_data )
             gtk_widget_set_sensitive(GTK_WIDGET
                                      (app_ui_data->menuitem_paste), TRUE);
         }
-        gchar *tmp = gtk_editable_get_chars(GTK_EDITABLE(focus), 0, -1);
-        if (strlen(tmp) != 0)   //there is something to be select-all'ed
-            gtk_widget_set_sensitive(GTK_WIDGET
+        else {
+            hildon_helper_set_insensitive_message(GTK_WIDGET
+                                                  (app_ui_data->menuitem_paste),
+                                                  _("rss_ib_unable_to_paste"));
+        }
+        gchar *tmp = NULL;
+        tmp = gtk_editable_get_chars(GTK_EDITABLE(focus), 0, -1);
+        if (tmp != NULL) {
+            if (strlen(tmp) != 0)
+                gtk_widget_set_sensitive(GTK_WIDGET
                                      (app_ui_data->menuitem_selectall), TRUE);
-        g_free(tmp);
+            g_free(tmp);
+        }
     }
 
     /* htmlwidget checking... */
@@ -2432,7 +2446,6 @@ gboolean ui_update_edit_menu( gpointer user_data )
             gtk_widget_set_sensitive(GTK_WIDGET
                                      (app_ui_data->menuitem_selectall), TRUE);
     }
-    paste_insens_messages(app_ui_data);
 
     return FALSE;
 }
