@@ -285,10 +285,12 @@ void item_set_read(itemPtr ip)
 void item_free(itemPtr ip)
 {
 
-    if (FALSE == ip->readStatus)
-        feed_decrease_unread_counter(ip->fp);
-    if (TRUE == ip->newStatus)
-        feed_decrease_new_counter(ip->fp);
+    if (ip->fp) {
+	if (FALSE == ip->readStatus)
+	    feed_decrease_unread_counter(ip->fp);
+	if (TRUE == ip->newStatus)
+	    feed_decrease_new_counter(ip->fp);
+    }
 
     g_free(ip->title);
     g_free(ip->source);
@@ -297,7 +299,9 @@ void item_free(itemPtr ip)
     g_free(ip->description);
     g_free(ip->id);
     g_assert(NULL == ip->tmpdata);  /* should be free after rendering */
-    metadata_list_free(ip->metadata);
+    if (ip->metadata) {
+	metadata_list_free(ip->metadata);
+    }
 
     // only assert when ip is not in vfolder
     if (ip->sourceFeed == NULL)
@@ -306,21 +310,6 @@ void item_free(itemPtr ip)
     g_free(ip);
 }
 
-void item_free_ignore_metadata(itemPtr ip)
-{
-    g_free(ip->title);
-    g_free(ip->source);
-    g_free(ip->real_source_url);
-    g_free(ip->real_source_title);
-    g_free(ip->description);
-    g_free(ip->id);
-    g_assert(NULL == ip->tmpdata);  /* should be free after rendering */
-
-    g_assert(ip->ui_data == NULL);
-
-    g_free(ip);
-}
-
 static void remove_link_from_cache(gchar * link, gpointer user_data)
 {
     file_cache_remove(FILE_CACHE(user_data), link);
