@@ -166,13 +166,6 @@ void item_set_new_status(itemPtr ip, const gboolean newStatus);
  */
 void item_set_mark(itemPtr ip, const gboolean flag);
 
-/**
- * Frees an item but ignores metadata
- *
- * @param ip the item to free
- */
-void item_free_ignore_metadata(itemPtr ip);
-
 void remove_links_from_cache(itemPtr ip);
 
 #endif
