@@ -36,7 +36,7 @@
 
 #include <sys/types.h>          /* For getpid(2) */
 
-#include <osso-ic-gconf.h>
+#include <conic.h>
 
 #include <unistd.h>             /* For gethostname(), readlink(2) and symlink(2) */
 #include <string.h>
