@@ -563,17 +563,20 @@ static void ocs_parse(feedPtr fp, xmlDocPtr doc, xmlNodePtr cur)
         /* after parsing we fill in the infos into the feedPtr structure */
         feed_add_items_delete_old(fp, items);
         feed_set_update_interval(fp, -1);
-        fp->title = dp->tags[OCS_TITLE];
+        if (dp)
+        {
+            fp->title = dp->tags[OCS_TITLE];
 
-        if (0 == error) {
-            fp->description = showDirectoryInfo(dp, fp->source);
-            feed_set_available(fp, TRUE);
-        } else {
-            ULOG_DEBUG("Ocs dir: there were errors while parsing this feed!");
-            fp->title = g_strdup(fp->source);
+            if (0 == error) {
+                fp->description = showDirectoryInfo(dp, fp->source);
+                feed_set_available(fp, TRUE);
+            } else {
+                ULOG_DEBUG("Ocs dir: there were errors while parsing this feed!");
+                fp->title = g_strdup(fp->source);
+            }
+
+            g_free(dp);
         }
-
-        g_free(dp);
     } while (FALSE);
 }
 
