@@ -160,6 +160,8 @@ void init_app_state(AppState * app_state)
     app_state->current_feed_depth = 0;
     app_state->fullscreen = FALSE;
     app_state->vertical_scroll_window_position = 0;
+    app_state->shown_dialog = DIALOG_NONE;
+    app_state->add_feed_url = NULL;
 }
 
 
@@ -270,6 +272,19 @@ void construct_app_state(AppState * app_state)
     g_assert(app_data->app_ui_data != NULL);
 
     app_state->fullscreen = app_data->app_ui_data->fullscreen;
+
+    if (app_data->app_ui_data->add_feed_dialog != NULL) {
+        GtkWidget *src = NULL;
+        app_state->shown_dialog = DIALOG_ADD_FEED;
+        src = lookup_widget(app_data->app_ui_data->dialog,"sourceEntry");
+        if (src != NULL) {
+            const gchar *srcUrl = NULL;
+            srcUrl = gtk_entry_get_text(GTK_ENTRY(src));
+            if (srcUrl != NULL) {
+                app_state->add_feed_url = g_strdup(srcUrl);
+            }
+        }
+    }
 }
 
 
@@ -297,15 +312,17 @@ void update_app_state(const AppState * app_state)
         if (root_folder == NULL) {
             g_warning("root folder not set");
         }
-        if (root_folder->ui_data == NULL) {
+        else if (root_folder->ui_data == NULL) {
             g_warning("error in root folder (ui_data NULL)");
         }
-        root_iter = ((ui_data *) (root_folder->ui_data))->row;
-        search_result = search_store(GTK_TREE_MODEL(feedstore),
-                                     &root_iter,
-                                     &result_iter,
-                                     app_state->current_feed,
-                                     1, app_state->current_feed_depth);
+        else {
+            root_iter = ((ui_data *) (root_folder->ui_data))->row;
+            search_result = search_store(GTK_TREE_MODEL(feedstore),
+                                         &root_iter,
+                                         &result_iter,
+                                         app_state->current_feed,
+                                         1, app_state->current_feed_depth);
+        }
 
         if (search_result) {
             ui_feedlist_convert_store_iter_to_visible_iter(&visible_iter,
@@ -334,6 +351,20 @@ void update_app_state(const AppState * app_state)
     g_assert(app_data->app_ui_data != NULL);
 
     ui_set_fullscreen_state(app_data->app_ui_data, FALSE, TRUE);
+    switch(app_state->shown_dialog) {
+        case DIALOG_NONE:
+            break;
+        case DIALOG_ADD_FEED:
+            on_newbtn_clicked(app_data,app_state->add_feed_url);
+            break; 
+        case DIALOG_MANAGE_FOLDERS:
+        case DIALOG_FEED_DETAILS:
+        case DIALOG_FEED_UNSUBSCRIBE:
+        case DIALOG_FEED_DIRECTORY:
+        default:
+            g_warning("Dialog State Not Implemented for this dialog");
+            break;
+    }
 }
 
 
@@ -400,6 +431,10 @@ GKeyFile *save_app_state_to_key_file(AppState * app_state)
                            STATE_KEY_FILE_GROUP,
                            STATE_KEY_FULLSCREEN, app_state->fullscreen);
 
+    g_key_file_set_integer(key_file,STATE_KEY_FILE_GROUP, STATE_KEY_SHOWN_DIALOG,app_state->shown_dialog);
+
+    g_key_file_set_string(key_file,STATE_KEY_FILE_GROUP,STATE_KEY_ADD_FEED_URL,app_state->add_feed_url);
+
     g_key_file_set_integer(key_file, STATE_KEY_FILE_GROUP, STATE_KEY_SCROLL_POSITION, 1);
 
     return key_file;
@@ -558,7 +593,19 @@ gboolean load_app_state_from_key_file(AppState * app_state,
         g_key_file_get_integer(key_file,
                                STATE_KEY_FILE_GROUP,
                                STATE_KEY_SCROLL_POSITION, &err);
+    check_read_error(&err, &result);
 
+    app_state->shown_dialog =
+        g_key_file_get_integer(key_file,
+                               STATE_KEY_FILE_GROUP,
+                               STATE_KEY_SHOWN_DIALOG, &err);
+    check_read_error(&err, &result);
+
+
+    app_state->add_feed_url =
+        g_key_file_get_string(key_file,
+                               STATE_KEY_FILE_GROUP,
+                               STATE_KEY_ADD_FEED_URL, &err);
     check_read_error(&err, &result);
 
     return result;
