@@ -36,6 +36,9 @@
 #define STATE_KEY_CURRENT_FEED "current_feed"
 #define STATE_KEY_SCROLL_POSITION "scroll_position"
 #define STATE_KEY_FULLSCREEN "fullscreen"
+#define STATE_KEY_SHOWN_DIALOG "shown_dialog"
+#define STATE_KEY_ADD_FEED_URL "add_feed_url"
+
 
 #define STATE_MAX_PATH_DEPTH 15
 
@@ -52,11 +55,24 @@ typedef enum {
 } StateSaveResultCode;
 
 
+/* Currently only ADD_FEED is implemented, maybe this more will be added
+ * later? */
+enum {
+    DIALOG_NONE = 0,
+    DIALOG_ADD_FEED,
+    DIALOG_MANAGE_FOLDERS,
+    DIALOG_FEED_DETAILS,
+    DIALOG_FEED_UNSUBSCRIBE,
+    DIALOG_FEED_DIRECTORY
+};
+
 typedef struct {
     gchar **current_feed;
     gint current_feed_depth;
     gboolean fullscreen;
     gint vertical_scroll_window_position;
+    gint shown_dialog;
+    gchar *add_feed_url;
 } AppState;
 
 
