@@ -130,10 +130,20 @@ ui_dnd_feed_drop_possible(GtkTreeDragDest * drag_dest,
         nodePtr ptr;
 
         gtk_tree_model_get(tree_model, &iter, FS_PTR, &ptr, -1);
+
+        if (ptr == NULL) 
+            return TRUE;
+        
         folderPtr fptr = ui_feedlist_get_target_folder_ptr(ptr);
+
         if (fptr && (fptr != ui_feedlist_get_root_folder()) &&
             folder_get_nonremovable(fptr))
             return FALSE;
+
+        if (fptr && fptr->root == TRUE ) 
+            return FALSE;
+
+
     } else {
         /* we come here if a drop on a feed happens */
         return FALSE;
@@ -204,14 +214,20 @@ void on_feedlist_drag_begin(GtkWidget * widget,
     else if (app_data->app_ui_data->draggednode->type == FST_FEED) {
         fp = (feedPtr) app_data->app_ui_data->draggednode;
         pixbuf = fp->icon;
+        if (pixbuf == NULL) {
+            pixbuf = icons[ICON_RSS_NEWS_FEED];
+        }
     }
-    w = gdk_pixbuf_get_width(pixbuf);
-    h = gdk_pixbuf_get_height(pixbuf);
 
-    gtk_drag_set_icon_pixbuf(drag_context, pixbuf, w, h);
-    // No need for this as pixbuf is just a reference to the feed icon
-    //g_object_unref(pixbuf);
-    pixbuf = NULL;
+    if (pixbuf != NULL) {
+        w = gdk_pixbuf_get_width(pixbuf);
+        h = gdk_pixbuf_get_height(pixbuf);
+
+        gtk_drag_set_icon_pixbuf(drag_context, pixbuf, w, h);
+        // No need for this as pixbuf is just a reference to the feed icon
+        // g_object_unref(pixbuf);
+        pixbuf = NULL;
+    }
     g_signal_stop_emission_by_name(widget, "drag-begin");
 }
 
