@@ -332,7 +332,8 @@ ui_feed_newdialog_can_close(struct fp_prop_ui_data * ui_data, gboolean msg,
                (strncasecmp(source, "https://", 8) != 0) &&
                (strncasecmp(source, "file://", 7) != 0) &&
                (strncasecmp(source, "obex://", 7) != 0) &&
-               (strncasecmp(source, "feed://", 7) != 0)) {
+               (strncasecmp(source, "feed://", 7) != 0) &&
+               (strncasecmp(source, "smb://", 6) != 0)) {
         if (msg)
             hildon_banner_show_information(GTK_WIDGET
                                            (app_data->app_ui_data->main_view),
@@ -419,6 +420,9 @@ on_newdialog_response(GtkDialog * dialog, gint response_id,
                 hildon_helper_set_insensitive_message(GTK_WIDGET
                                                       (ui_data->newfeedbtn),
                                                       _("rss_ib_subcribe_already_started"));
+                hildon_helper_set_insensitive_message(GTK_WIDGET
+                                                      (app_data->app_ui_data->browsebtn),
+                                                      _("rss_ib_subcribe_already_started"));
                 ui_feedlist_new_subscription(source, NULL,
                                              FEED_REQ_RESET_TITLE |
                                              FEED_REQ_RESET_UPDATE_INT |
@@ -431,6 +435,8 @@ on_newdialog_response(GtkDialog * dialog, gint response_id,
         case GTK_RESPONSE_CANCEL:
         case GTK_RESPONSE_DELETE_EVENT:
 
+            app_data->app_ui_data->iap_action = OSSO_IAP_NO_ACTION;
+
             if (SFM_REFRESH == app_ui_data->search_mode) {
                 app_ui_data->search_mode = SFM_INTERRUPTED;
                 download_cancel_all(TRUE);
@@ -487,11 +493,25 @@ feed_prop_can_close(struct fp_prop_ui_data * ui_data, gboolean show,
                                            _("rss_ni_no_web_address_for_feed"));
         
 
+            gtk_widget_grab_focus(ui_data->feedLocationEntry);
+        }
+        return FALSE;
+    } else if ((strncasecmp(source, "http://", 7) != 0) && (strncasecmp(source, "https://", 8) != 0) &&
+               (strncasecmp(source, "file://", 7) != 0) && (strncasecmp(source, "obex://", 7) != 0) &&
+               (strncasecmp(source, "feed://", 7) != 0)) {
+        if (show) {
+            hildon_banner_show_information(GTK_WIDGET
+                                           (app_data->app_ui_data->main_view),
+                                           NULL,
+                                           _("rss_ni_no_web_address_for_feed"));
+        
+
             gtk_widget_grab_focus(ui_data->feedLocationEntry);
         }
         return FALSE;
     }
 
+
     if (ptitle)
         *ptitle = (gchar *) title;
     if (psource)
@@ -573,6 +593,7 @@ on_propdialog_response(GtkDialog * dialog, gint response_id,
         app_ui_data->dlg_btn_unsubscribe = NULL;
         g_free(ui_data);
         app_ui_data->dialog = NULL;
+        app_ui_data->propdialog = NULL;
         gtk_widget_destroy(GTK_WIDGET(dialog));
     }
 }
@@ -1008,7 +1029,6 @@ void ui_feed_process_update_result(struct request *request)
 /** updating of a single feed list entry */
 void ui_feed_update(feedPtr fp)
 {
-    GtkTreeModel *model = NULL;
     GtkTreeIter *iter = NULL;
     gchar *label = NULL, *tmp = NULL;
     int unread = 0, marked = 0;
@@ -1017,7 +1037,6 @@ void ui_feed_update(feedPtr fp)
         return;
 
     iter = &((ui_data *) fp->ui_data)->row;
-    model = GTK_TREE_MODEL(feedstore);
 
     g_assert(FST_FOLDER != fp->type);
 
@@ -1271,8 +1290,6 @@ void newdialog_return_to_normal()
 {
     g_assert(app_data != NULL);
     g_assert(app_data->app_ui_data != NULL);
-    g_assert(app_data->app_ui_data->ui_data != NULL);
-
 
     if (app_data->app_ui_data->add_feed_dialog != NULL) 
         gtk_window_set_modal(GTK_WINDOW(app_data->app_ui_data->add_feed_dialog), TRUE);
@@ -1282,7 +1299,10 @@ void newdialog_return_to_normal()
         gtk_widget_set_sensitive(app_data->app_ui_data->changefolderbtn, TRUE);
     if (app_data->app_ui_data->browsebtn != NULL) 
         gtk_widget_set_sensitive(app_data->app_ui_data->browsebtn, TRUE);
-    if (app_data->app_ui_data->ui_data->sourceEntry != NULL) 
+
+    // some cases ui_data might allready be null when this is called so to
+    // prevent crash, assert removed above and additional test here: 
+    if (app_data->app_ui_data->ui_data != NULL && app_data->app_ui_data->ui_data->sourceEntry != NULL) 
         gtk_widget_set_sensitive(app_data->app_ui_data->ui_data->sourceEntry, TRUE);
 }
 
