@@ -407,7 +407,7 @@ static void ui_feed_directory_parse(gchar * data, size_t length)
     while (cur && xmlIsBlankNode(cur)) {
         cur = cur->next;
     }
-    if (NULL == cur->name) {
+    if (!cur || (NULL == cur->name)) {
         g_debug("Invalid XML. Unable to parse feed directory. ");
 
         if (doc != NULL)
