@@ -38,7 +38,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkevents.h>
 #include <hildon/hildon-banner.h>
-#include <osso-ic-gconf.h>
+#include <conic.h>
 
 #define DBUS_API_SUBJECT_TO_CHANGE
 #include <osso-rss-feed-reader/settings.h>
@@ -293,10 +293,11 @@ gboolean ui_feedlist_check_if_folder_empty(folderPtr folder)
         g_assert(iter != NULL);
         child_count = gtk_tree_model_iter_n_children
             (GTK_TREE_MODEL(feedstore), iter);
-        gtk_tree_model_iter_children(GTK_TREE_MODEL(feedstore),
-                                     &child_iter, iter);
-        gtk_tree_model_get(GTK_TREE_MODEL(feedstore), &child_iter,
-                           FS_PTR, &child_node, -1);
+        if(gtk_tree_model_iter_children(GTK_TREE_MODEL(feedstore),
+                                        &child_iter, iter)) {
+            gtk_tree_model_get(GTK_TREE_MODEL(feedstore), &child_iter,
+                               FS_PTR, &child_node, -1);
+        }
         /* An empty folder should have the "No feeds" element. */
         return !(child_count >= 2 || (child_count == 1 && child_node != NULL)); 
     }
@@ -856,6 +857,10 @@ ui_feedlist_selection_changed_cb(GtkTreeSelection * treeselection,
     app_ui_data = app_data->app_ui_data;
 
     nodePtr ptr = (nodePtr) ui_feedlist_get_selected();
+
+    if(app_data->app_ui_data->search_mode == SFM_SEARCH)
+    return;	    
+	    
     if (NULL == ptr) {
         /* "no feeds" label clicked */
         gtk_widget_set_sensitive(GTK_WIDGET(app_ui_data->menuitem_open),
@@ -1307,8 +1312,7 @@ ui_feedlist_new_subscription_for_fd(const gchar * source,
                              FEED_REQ_DOWNLOAD_FAVICON |
                              FEED_REQ_AUTH_DIALOG);
 #else
-        gconf_client_clear_cache(app_data->gconf_client);
-        if (*getStringConfValue(ICD_GCONF_CURRENT)) {
+        if (app_data->app_ui_data->network_iap) {
             app_data->app_ui_data->connect_at_the_end = FALSE;
             feed_schedule_update(fp,
                                  flags | FEED_REQ_PRIORITY_HIGH |
@@ -1366,7 +1370,7 @@ void on_newbtn_clicked_cb(GtkButton * button, gpointer user_data)
         gtk_widget_show(newdialog);
 }
 
-/* Used in handling "mime_open" dbus signal
+/* Used in handling "mime_open" dbus signal and state restoring
  */
 void on_newbtn_clicked(AppData * appdata, const gchar * fd_source)
 {
@@ -1742,10 +1746,11 @@ gboolean ui_feedlist_confirm_and_delete_folder(folderPtr folder)
         g_assert(iter != NULL);
         child_count = gtk_tree_model_iter_n_children
             (GTK_TREE_MODEL(feedstore), iter);
-        gtk_tree_model_iter_children(GTK_TREE_MODEL(feedstore),
-                                     &child_iter, iter);
-        gtk_tree_model_get(GTK_TREE_MODEL(feedstore), &child_iter,
-                           FS_PTR, &child_node, -1);
+        if (gtk_tree_model_iter_children(GTK_TREE_MODEL(feedstore),
+                                         &child_iter, iter)) {
+            gtk_tree_model_get(GTK_TREE_MODEL(feedstore), &child_iter,
+                               FS_PTR, &child_node, -1);
+        }
         /* An empty folder should have the "No feeds" element. */
         if (child_count >= 2 || (child_count == 1 && child_node != NULL)) {
             g_assert(app_data != NULL);
