@@ -354,14 +354,21 @@ void create_folder_rename_dialog(folderPtr folder)
 
 void on_foldernamechangebtn_clicked(GtkButton * button, gpointer user_data)
 {
-    gchar *title = NULL;
+    gchar *tmp= NULL;
+    gchar *title= NULL;
     folderPtr folder = NULL;
     GtkWidget *foldernameentry;
     GtkTreeIter parent_iter;
 
     folder = gtk_object_get_data(GTK_OBJECT(foldernamedialog), "folder");
     foldernameentry = lookup_widget(foldernamedialog, "foldernameentry");
-    title = (gchar *) gtk_entry_get_text(GTK_ENTRY(foldernameentry));
+    tmp = (gchar *) gtk_entry_get_text(GTK_ENTRY(foldernameentry));
+
+    /* strip leading and trailing whitespaces tmp dup'ed since its pointer to
+     * widgets internal memory */  
+
+    title = g_strdup(tmp);    
+    title = g_strstrip(title);
 
     if (!strcmp(title, "")) {
         hildon_banner_show_information(GTK_WIDGET
@@ -370,11 +377,13 @@ void on_foldernamechangebtn_clicked(GtkButton * button, gpointer user_data)
                                        dgettext
                                        (HILDON_COMMON_STRINGS_L10N_PACKAGE,
                                         "ckdg_ib_enter_name"));
+        g_free(title);
         return;
     }
     if (strcmp(title, folder->title) == 0) {
         /*TODO: just hide ? */
         gtk_widget_hide(foldernamedialog);
+        g_free(title);
         return;
     }
     /* get the parent iter of this folder */
@@ -398,6 +407,7 @@ void on_foldernamechangebtn_clicked(GtkButton * button, gpointer user_data)
                                        dgettext
                                        (HILDON_COMMON_STRINGS_L10N_PACKAGE,
                                         "ckdg_ib_folder_already_exists"));
+    g_free(title);
 }
 
 void ui_folder_remove(gpointer callback_data, guint callback_action,
@@ -527,8 +537,8 @@ void ui_folder_empty_check(folderPtr folder)
         return;
 
     /* else we could have case 2 */
-    gtk_tree_model_iter_children(GTK_TREE_MODEL(feedstore), &iter, parent);
-    do {
+    valid = gtk_tree_model_iter_children(GTK_TREE_MODEL(feedstore), &iter, parent);
+    while (valid) {
         gtk_tree_model_get(GTK_TREE_MODEL(feedstore), &iter, FS_PTR, &ptr,
                            -1);
 
@@ -538,7 +548,7 @@ void ui_folder_empty_check(folderPtr folder)
         }
 
         valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(feedstore), &iter);
-    } while (valid);
+    };
 }
 
 void ui_folder_handle_empty_root()
@@ -655,6 +665,9 @@ void ui_folder_collapse_expand_cb(GtkTreeView * widget,
     if (!lifereaStarted)
         return;
 
+    if(app_data->app_ui_data->search_mode == SFM_SEARCH)
+    return;
+    
     g_assert(NULL != iter);
 
     model = GTK_TREE_MODEL(feedstore);
