@@ -175,6 +175,10 @@ void ui_mainwindow_set_mode(gboolean threePane)
                          "focus-in-event",
                          G_CALLBACK(on_html_scrollpane_focus_in), app_data);
 
+        g_signal_connect(G_OBJECT (gtk_bin_get_child (GTK_BIN(app_data->app_ui_data->html_scrollpane))),
+                         "expose-event",
+                         G_CALLBACK(on_gtkhtml_expose), NULL);
+
         g_signal_connect(G_OBJECT (gtk_bin_get_child (GTK_BIN(app_data->app_ui_data->html_scrollpane))),
                          "key-press-event",
                          G_CALLBACK(on_gtkhtml_keyboard_event), app_data);
@@ -506,8 +510,9 @@ void ui_create_toolbar(AppUIData * app_ui_data)
     g_signal_connect(G_OBJECT(app_ui_data->main_view),
                      "key_press_event",
                      G_CALLBACK(key_press_with_hidden_toolbar), NULL);
+    app_ui_data->toolbar_keypress_handler_blocked = FALSE;
 
-    gtk_widget_show(app_ui_data->main_toolbar);
+    gtk_widget_show_all(app_ui_data->main_toolbar);
 
     gtk_toolbar_set_orientation(GTK_TOOLBAR(app_ui_data->main_toolbar),
                                 GTK_ORIENTATION_HORIZONTAL);
@@ -587,6 +592,8 @@ void ui_create_toolbar(AppUIData * app_ui_data)
         g_assert(search_field_entry);
         g_signal_connect(G_OBJECT(search_field_entry), "key-press-event",
                          G_CALLBACK(on_search_field_key_press), app_ui_data);
+        g_signal_connect(G_OBJECT(search_field_entry), "focus-out-event",
+                         G_CALLBACK(on_search_field_focus_out), app_ui_data);
     }
 
     app_ui_data->progress_bar = gtk_progress_bar_new();
@@ -596,10 +603,6 @@ void ui_create_toolbar(AppUIData * app_ui_data)
                       GTK_WIDGET(app_ui_data->search_field));
     gtk_toolbar_insert(GTK_TOOLBAR(app_ui_data->main_toolbar),
                        GTK_TOOL_ITEM(toolitem), -1);
-    g_signal_connect(G_OBJECT(app_ui_data->search_field),
-                     "focus-out-event",
-                     G_CALLBACK(hide_temp_shown_toolbar), NULL);
-
     ADD_TOOLBAR_BUTTON(search_button, "qgn_toolb_browser_gobutton",
                        on_searchentry_activate)
         app_ui_data->search_button = GTK_TOOL_BUTTON(search_button);
@@ -611,7 +614,7 @@ void ui_create_toolbar(AppUIData * app_ui_data)
     gtk_toolbar_set_style(GTK_TOOLBAR(app_ui_data->main_toolbar),
                           GTK_TOOLBAR_ICONS);
 
-    hildon_program_set_common_toolbar(app_ui_data->app,
+    hildon_window_add_toolbar(app_ui_data->main_view,
                                       GTK_TOOLBAR(app_ui_data->main_toolbar));
 
     app_ui_data->button_image_stop =
@@ -708,10 +711,10 @@ void ui_set_toolbar_full_menu_item_state(AppUIData * app_ui_data,
     g_assert(app_ui_data != NULL);
 
     g_signal_handlers_block_by_func(G_OBJECT(app_ui_data->menuitem_full),
-                                    G_CALLBACK(toggle_toolbar), NULL);
+                                    G_CALLBACK(toggle_toolbar_cb), app_ui_data);
     gtk_check_menu_item_set_active(app_ui_data->menuitem_full, state);
     g_signal_handlers_unblock_by_func(G_OBJECT(app_ui_data->menuitem_full),
-                                      G_CALLBACK(toggle_toolbar), NULL);
+                                      G_CALLBACK(toggle_toolbar_cb), app_ui_data);
 }
 
 void ui_set_toolbar_normal_menu_item_state(AppUIData * app_ui_data,
@@ -720,11 +723,11 @@ void ui_set_toolbar_normal_menu_item_state(AppUIData * app_ui_data,
     g_assert(app_ui_data != NULL);
 
     g_signal_handlers_block_by_func(G_OBJECT(app_ui_data->menuitem_normal),
-                                    G_CALLBACK(toggle_toolbar), NULL);
+                                    G_CALLBACK(toggle_toolbar_cb), app_ui_data);
     gtk_check_menu_item_set_active(app_ui_data->menuitem_normal, state);
     g_signal_handlers_unblock_by_func(G_OBJECT
                                       (app_ui_data->menuitem_normal),
-                                      G_CALLBACK(toggle_toolbar), NULL);
+                                      G_CALLBACK(toggle_toolbar_cb), app_ui_data);
 }
 
 
@@ -749,7 +752,6 @@ void ui_set_fullscreen_state(AppUIData * app_ui_data,
                              gboolean state, gboolean update_menu_item)
 {
     GtkWidget *toolbar;
-    gboolean show_toolbar = FALSE;
 
     g_assert(app_ui_data != NULL);
 
@@ -758,25 +760,13 @@ void ui_set_fullscreen_state(AppUIData * app_ui_data,
     if (state) {
         gtk_window_fullscreen(GTK_WINDOW(app_ui_data->main_view));
         app_ui_data->fullscreen = TRUE;
-        show_toolbar = gtk_check_menu_item_get_active
-            (app_ui_data->menuitem_full);
-
         ULOG_INFO("Application now in fullscreen mode");
     } else {
         gtk_window_unfullscreen(GTK_WINDOW(app_ui_data->main_view));
         app_ui_data->fullscreen = FALSE;
-        show_toolbar = gtk_check_menu_item_get_active
-            (app_ui_data->menuitem_normal);
         ULOG_INFO("Application now out of fullscreen mode.");
     }
-    if (show_toolbar) {
-        gtk_widget_show(toolbar);
-    }
-    // should always show toolbar if not in normal mode as user needs to see the
-    // progressbar
-    else if (app_ui_data->search_mode == SFM_NORMAL) {
-        gtk_widget_hide(toolbar);
-    }
+    toggle_toolbar_cb(NULL,app_ui_data);
     if (update_menu_item) {
         ui_set_fullscreen_menu_item_state(app_ui_data, state);
     }
@@ -848,14 +838,21 @@ ui_show_feed_delete_confirmation(AppUIData * app_ui_data, gchar * feed_title)
     gint resp1 = CONFRESP_ERROR;
     ConfirmationResponse resp = CONFRESP_ERROR;
     gchar *str = NULL, *str2 = NULL;
+    GtkWidget *parent;
 
     str = g_strdup_printf("%s", _("rss_nc_are_you_sure_unsubscribe"));
     str2 = g_strdup_printf(str, feed_title ? feed_title : "");
 
+    if (app_ui_data->propdialog) {
+        ULOG_DEBUG("unsubs from propdialog");
+        parent = app_ui_data->propdialog;
+    } else {
+        parent = GTK_WIDGET(app_ui_data->main_view);
+    }
 
     note =
         HILDON_NOTE(hildon_note_new_confirmation_add_buttons
-                    (GTK_WINDOW(app_ui_data->main_view), str2, _("rss_bd_ok"),
+                    (GTK_WINDOW(parent), str2, _("rss_bd_ok"),
                      CONFRESP_OK, _("rss_bd_cancel"), CONFRESP_CANCEL, NULL,
                      NULL));
     app_ui_data->unsubscribe_dialog = GTK_WIDGET(note);
@@ -882,8 +879,13 @@ ui_show_feed_delete_confirmation(AppUIData * app_ui_data, gchar * feed_title)
     }
     while (resp1 == CONFRESP_OK && SFM_REFRESH == app_ui_data->search_mode);
 
-    gtk_widget_destroy(GTK_WIDGET(note));
-    app_ui_data->unsubscribe_dialog = NULL;
+    if (app_ui_data->unsubscribe_dialog) {
+            /* it can be already destroyed and set to NULL if 
+             * OSSO_RSS_FEED_READER_ADD_SIGNAL was cought on dbus */
+            gtk_widget_destroy(app_ui_data->unsubscribe_dialog);
+            app_ui_data->unsubscribe_dialog = NULL;
+    }
+
     g_free(str);
     g_free(str2);
     str = NULL;
@@ -956,8 +958,10 @@ void ui_mainwindow_save_search_entries()
     for (i = 0; i < search_string_count; i++) {
         gtk_combo_box_set_active(search_combo, i);
         entry_text = gtk_combo_box_get_active_text(search_combo);
-        cache_write_str(file, entry_text);
-        ULOG_DEBUG("Wrote: %s", entry_text);
+        if (cache_write_str(file, entry_text))
+        {
+            ULOG_DEBUG("Wrote: %s", entry_text);
+        }
         g_free(entry_text);
     }
     fclose(file);
