@@ -269,7 +269,7 @@ void on_searchentry_activate(GtkButton * button, gpointer user_data)
     switch_progressbar(PROGRESSBAR_SEARCH_MODE);
 
     ui_mainwindow_set_search(TRUE);
-
+    app_ui_data->feedlist_lastnode = ui_feedlist_get_selected();
     ui_feedlist_select(NULL);
 
     ui_itemlist_search_init();  /* unloading stuff */
@@ -301,6 +301,7 @@ void on_searchresults_menuitem_selected(GtkWidget * menuitem,
 
     ULOG_DEBUG("on_searchresults_menuitem_selected");
     gtkhtml_block_tap_and_hold_signal();
+    app_data->app_ui_data->feedlist_lastnode = ui_feedlist_get_selected();
     ui_feedlist_select(NULL);
     //feeds might have been deleted. So we need this
     ui_mainwindow_construct_search_view();
