@@ -223,14 +223,14 @@ gboolean pop_request(struct request ** request)
 void update_download_finished(struct request *nrequest)
 {
     /**the remaining part of download_process**/
-    if (nrequest->httpstatus >= 400) {
+    if (nrequest && (nrequest->httpstatus >= 400)) {
         g_free(nrequest->data);
         nrequest->data = NULL;
         nrequest->size = 0;
     }
 
 
-    if (nrequest->jump) {       //not continuing, the download_process was not called from the download_thread_main
+    if (nrequest && (nrequest->jump)) {       //not continuing, the download_process was not called from the download_thread_main
         feed_parse_new_download(nrequest);
         return;
     }
@@ -510,6 +510,7 @@ gboolean download_process(struct request *request)
     if ((strncasecmp(request->source, "http://", 7) == 0) ||
                (strncasecmp(request->source, "https://", 8) == 0) ||
                (strncasecmp(request->source, "file://", 7) == 0) ||
+               (strncasecmp(request->source, "smb://", 6) == 0) ||
                (strncasecmp(request->source, "obex://", 7) == 0)) {
 
         /*tvh: IMPORTANT here we need to process local files as well 
@@ -525,14 +526,16 @@ gboolean download_process(struct request *request)
         inc_counter(C_RSS_CURRENT);
         call_update_progressbar(NULL);
 
-        feed_set_available(request->feed, FALSE);
-        ui_feed_update(request->feed);
+        if (request->feed) {
+            feed_set_available(request->feed, FALSE);
+            ui_feed_update(request->feed);
+        }
         
         download_request_free(&request);
 
         update_req_ended();
         
-        return TRUE;
+        return FALSE;
     }
 
     return FALSE;
@@ -772,7 +775,7 @@ void download_queue_image(const gchar * url, gpointer data,
     //there ...
     size_t size;
     gpointer cdata = file_cache_find(app_data->app_ui_data->img_cache,
-                                     url, &size, TRUE);
+                                     url, &size, FALSE);
     if (cdata) {
         //ULOG_DEBUG("#####Found in cache %s: ", url);
 
@@ -868,8 +871,11 @@ gboolean remove_all(gpointer key, gpointer value, gpointer user_data)
     return TRUE;
 }
 
+extern gchar *prev_find_text;
 static void update_progress_finalize(gboolean show_banner)
 {
+    prev_find_text = NULL;
+
     gtkhtml_load_images(FALSE);
 
 
